import { useEffect } from 'react';
import uniqBy from 'lodash.uniqby';
import { getChannel } from '../../../utils/getChannel';
import { useChatContext } from '../../../context/ChatContext';
export const useChannelVisibleListener = (setChannels, customHandler) => {
    const { client } = useChatContext('useChannelVisibleListener');
    useEffect(() => {
        const handleEvent = async (event) => {
            if (customHandler && typeof customHandler === 'function') {
                customHandler(setChannels, event);
            }
            else if (event.type && event.channel_type && event.channel_id) {
                const channel = await getChannel({
                    client,
                    id: event.channel_id,
                    type: event.channel_type,
                });
                setChannels((channels) => uniqBy([channel, ...channels], 'cid'));
            }
        };
        client.on('channel.visible', handleEvent);
        return () => {
            client.off('channel.visible', handleEvent);
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [customHandler]);
};
